getValueAs<U> method
Get the immediate child of this node named name and its value at dir.
Implementation
U getValueAs<U>(String name, Folder dir) =>
_children[name]?.valueAt(dir) as U;
Get the immediate child of this node named name and its value at dir.
U getValueAs<U>(String name, Folder dir) =>
_children[name]?.valueAt(dir) as U;