Kind enum
Values
- accessor → const Kind
- constant → const Kind
- constructor → const Kind
- class_ → const Kind
- dynamic → const Kind
- enum_ → const Kind
- extension → const Kind
- extensionType → const Kind
- function → const Kind
- library → const Kind
- method → const Kind
- mixin → const Kind
- never → const Kind
- package → const Kind
- parameter → const Kind
- prefix → const Kind
- property → const Kind
- sdk → const Kind
- topic → const Kind
- topLevelConstant → const Kind
- topLevelProperty → const Kind
- typedef → const Kind
- typeParameter → const Kind
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited