NoFileWriter class
Used for the generateDocs:false option.
Writes nothing.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
writtenFiles
→ Set<
String> -
All filenames written by this generator.
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
write(
String filePath, String content, {Warnable? element}) → void -
Writes
contentto a file atfilePath.override -
writeBytes(
String filePath, List< int> content, {bool allowOverwrite = false}) → void -
Writes
contentto a file atfilePath.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited