write method
Writes content to a file at filePath.
If a file is to be overwritten, a warning will be reported on element.
Implementation
@override
void write(String filePath, String content, {Warnable? element}) {
// Do nothing
}
Writes content to a file at filePath.
If a file is to be overwritten, a warning will be reported on element.
@override
void write(String filePath, String content, {Warnable? element}) {
// Do nothing
}