allImplementersAdded property
It is safe to cache values derived from the _implementers table if this
is true.
Implementation
bool allImplementersAdded = false;
It is safe to cache values derived from the _implementers table if this
is true.
bool allImplementersAdded = false;