fullyQualifiedName property

String get fullyQualifiedName
inherited

A "fully" qualified name, used for things like for warnings printed in the terminal; not for display use in rendered HTML.

"Fully" means the name is qualified through the library. For example, a method named 'baz' in a class named 'Bar' in a library named 'foo' has a fully qualified name of 'foo.Bar.baz'.

As dartdoc can document multiple packages at once, note that such qualifying names may not be unique across all documented packages.

Implementation

String get fullyQualifiedName => name;