workspacePackageNames property

Set<String> workspacePackageNames
final

Names of packages that are workspace members, populated by the builder when workspaceDocs is enabled.

Used by Package.isLocal to determine if a package should be treated as local documentation.

Implementation

final Set<String> workspacePackageNames = {};