PackageMeta class abstract
Describes a single package in the context of dartdoc.
The primary function of this class is to allow canonicalization of packages by returning the same PackageMeta for a given filename, library or path if they belong to the same package.
Overriding this is typically done by overriding factories as rest of
dartdoc creates this object by calling these static factories.
- Implementers
Constructors
- PackageMeta(Folder dir, ResourceProvider resourceProvider)
Properties
- description → String
-
The package description from pubspec.yaml, or an empty string if not
available.
no setter
- dir → Folder
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- homepage → String
-
no setter
- hostedAt → String?
-
The hostname that the package is hosted at, usually 'pub.dev', or
nullif not a hosted pub package.no setter - isSdk → bool
-
Whether this represents a 'Dart' SDK.
no setter
- isValid → bool
-
Whether this is a valid package (valid enough to generate docs).
no setter
- name → String
-
no setter
- repository → String
-
no setter
- requiresFlutter → bool
-
no setter
- resolvedDir → String
-
no setter
- resourceProvider → ResourceProvider
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → String
-
no setter
Methods
-
getInvalidReasons(
) → List< String> - The list of reasons this package is invalid.
-
getReadmeContents(
) → File? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sdkType(
String? flutterRootPath) → String? -
Returns 'Dart' or 'Flutter' (preferentially, 'Flutter' when the answer is
"both"), or
nullif this package is not part of an SDK. -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override